[−][src]Enum base64::DecodeError
Errors that can occur while decoding.
Variants
InvalidByte(usize, u8)An invalid byte was found in the input. The offset and offending byte are provided.
InvalidLengthThe length of the input is invalid.
InvalidLastSymbol(usize, u8)The last non-padding input symbol's encoded 6 bits have nonzero bits that will be discarded. This is indicative of corrupted or truncated Base64. Unlike InvalidByte, which reports symbols that aren't in the alphabet, this error is for symbols that are in the alphabet but represent nonsensical encodings.